@@ -46,7 +46,7 @@ static const unsigned long _glibtop_sysdeps_cpu_smp_2_6 =
 /* Init function. */
 
 void
-glibtop_init_cpu_s (glibtop *server)
+_glibtop_init_cpu_s (glibtop *server)
 {
 	server->sysdeps.cpu = _glibtop_sysdeps_cpu;
 
@@ -73,8 +73,6 @@ glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 	char buffer [BUFSIZ], *p;
 	int i;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_CPU, 0);
-
 	memset (buf, 0, sizeof (glibtop_cpu));
 
 	file_to_buffer(server, buffer, FILENAME);
