@@ -38,7 +38,7 @@ static const unsigned long _glibtop_sysdeps_proc_mem_statm =
 /* Init function. */
 
 void
-glibtop_init_proc_mem_s (glibtop *server)
+_glibtop_init_proc_mem_s (glibtop *server)
 {
 	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem |
 	  _glibtop_sysdeps_proc_mem_statm;
@@ -52,8 +52,6 @@ glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf, pid_t pid)
 	char buffer [BUFSIZ], *p;
 	const size_t pagesize = get_page_size();
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
-
 	memset (buf, 0, sizeof (glibtop_proc_mem));
 
 	if (proc_stat_to_buffer (buffer, pid))
