@@ -40,7 +40,7 @@ static const unsigned long _glibtop_sysdeps_proc_time_smp =
 /* Init function. */
 
 void
-glibtop_init_proc_time_s (glibtop *server)
+_glibtop_init_proc_time_s (glibtop *server)
 {
 	server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
 
@@ -56,8 +56,6 @@ glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid)
 	char buffer [BUFSIZ], *p;
 	int i;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_TIME, 0);
-
 	memset (buf, 0, sizeof (glibtop_proc_time));
 
 	if (proc_stat_to_buffer (buffer, pid))
